/// <reference types="webpack" />
import * as _webpack from "webpack";
import { Configuration } from "webpack";
import { IToolsOptions } from "./interfaces";
export { Configuration, NewModule } from "webpack";
export * from "./synchronize";
export * from "./node";
export * from "./interfaces";
/**
 * Loaders ref.
 */
export declare const loaders: {
    typescriptLoaderFactory(): _webpack.Rule;
    cssLoaderFactory(): _webpack.Rule;
    lessLoaderFactory(lessLoaderOptions?: object): _webpack.Rule;
    sassLoaderFactory(sassLoaderOptions?: object): _webpack.Rule;
    imageLoaderFactory(options: IToolsOptions): _webpack.Rule;
    fontLoaderFactory(options: IToolsOptions): {
        test: RegExp;
        use: {
            loader: string;
            options: {
                name: string;
            };
        }[];
    };
};
/**
 * Plugins ref.
 */
export declare const plugins: {
    ExtractTextPlugin: any;
    HtmlWebpackPlugin: any;
    CopyPlugin: any;
    CleanWebpackPlugin: any;
};
/**
 * Autoprefix ref.
 */
export declare const autoprefixer: any;
/**
 * Webpack ref.
 */
export declare const webpack: typeof _webpack;
/**
 * Create a default webpack configuration.
 *
 * ```ts
 * import { createConfiguration } from "oly-tools";
 *
 * export default createConfiguration({
 *   entry: "./src/main.browser.tsx",
 * });
 * ```
 *
 * Even if it's cool to have a ready2go webpack configuration,
 * you should avoid this function and make your own configuration.
 *
 * ```ts
 * export default (env: string) => {
 *
 *  const config = createConfiguration({
 *   entry: "./src/main.browser.tsx",
 *  });
 *
 *  // edit config here
 *
 *  return config;
 * }
 * ```
 *
 * @param options {IToolsOptions}
 * @return {Configuration}
 */
export declare function createConfiguration(options: IToolsOptions): Configuration;
