"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var autoprefixer = require("autoprefixer");
var ExtractTextPlugin = require("extract-text-webpack-plugin");
/**
 * Typescript loader factory
 */
function typescriptLoaderFactory() {
    return {
        exclude: /node_modules/,
        test: /\.tsx?$/,
        use: [{
                loader: "ts-loader",
                options: {
                    silent: true,
                    transpileOnly: true,
                    compilerOptions: {
                        module: "es2015",
                    },
                },
            }],
    };
}
exports.typescriptLoaderFactory = typescriptLoaderFactory;
/**
 * CSS loader factory
 */
function cssLoaderFactory() {
    return {
        loader: ExtractTextPlugin.extract({
            fallback: "style-loader",
            use: [{ loader: "css-loader" }],
        }),
        test: /\.css$/,
    };
}
exports.cssLoaderFactory = cssLoaderFactory;
/**
 * Less loader factory
 *
 * @param lessLoaderOptions   less options
 */
function lessLoaderFactory(lessLoaderOptions) {
    if (lessLoaderOptions === void 0) { lessLoaderOptions = {}; }
    return {
        loader: ExtractTextPlugin.extract({
            fallback: "style-loader",
            use: [
                { loader: "css-loader" },
                { loader: "postcss-loader", options: { plugins: function () { return [autoprefixer]; } } },
                { loader: "less-loader", options: lessLoaderOptions },
            ],
        }),
        test: /\.(css|less)$/,
    };
}
exports.lessLoaderFactory = lessLoaderFactory;
/**
 * Sass loader factory
 *
 * @param sassLoaderOptions  sass options
 */
function sassLoaderFactory(sassLoaderOptions) {
    if (sassLoaderOptions === void 0) { sassLoaderOptions = {}; }
    return {
        loader: ExtractTextPlugin.extract({
            fallback: "style-loader",
            use: [
                { loader: "css-loader" },
                { loader: "postcss-loader", options: { plugins: function () { return [autoprefixer]; } } },
                { loader: "sass-loader", options: sassLoaderOptions },
            ],
        }),
        test: /\.(css|scss|sass)$/,
    };
}
exports.sassLoaderFactory = sassLoaderFactory;
/**
 * Image loader factory
 */
function imageLoaderFactory(options) {
    return {
        test: /\.(png|jpeg|jpg|svg)$/,
        use: [{
                loader: "file-loader",
                options: {
                    name: options.hash
                        ? "images/[name].[hash].[ext]"
                        : "images/[name].[ext]",
                },
            }],
    };
}
exports.imageLoaderFactory = imageLoaderFactory;
/**
 * Font loader factory
 */
function fontLoaderFactory(options) {
    return {
        test: /\.(ttf|otf|eot|woff(2)?)(\?[a-z0-9]+)?$/,
        use: [{
                loader: "file-loader",
                options: {
                    name: options.hash
                        ? "fonts/[name].[hash].[ext]"
                        : "fonts/[name].[ext]",
                },
            }],
    };
}
exports.fontLoaderFactory = fontLoaderFactory;
//# sourceMappingURL=loaders.js.map