"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var CleanWebpackPlugin = require("clean-webpack-plugin");
var CopyPlugin = require("copy-webpack-plugin");
var path_1 = require("path");
var webpack_1 = require("webpack");
var loaders_1 = require("./loaders");
var nodeExternals = require("webpack-node-externals");
/**
 *
 * @param options
 * @returns {Configuration}
 */
exports.createNodeConfiguration = function (options) {
    var config = {};
    var root = options.root || process.cwd();
    var env = typeof options.env === "object" ? options.env : {};
    var isProduction = (process.argv.indexOf("-p") > -1)
        || process.env.NODE_ENV === "production"
        || options.production === true
        || (!!env.production || env.NODE_ENV === "production");
    env.NODE_ENV = isProduction ? "production" : "development";
    options.entry = options.entry || "./src/index.ts";
    options.dist = options.dist || path_1.resolve(root, "out");
    options.typescriptLoader = options.typescriptLoader || loaders_1.typescriptLoaderFactory();
    // define the format of the source-map
    // set to false for disabled it
    config.devtool = "source-map";
    // set a default context (base)
    // it's the root directory for all relative path
    config.context = root;
    // main entry (or entries)
    // can be a single file or an object of file
    config.entry = options.entry;
    // resolve provides options to navigate into node_modules/sources
    config.resolve = {
        extensions: [".webpack.js", ".js", ".web.js", ".ts", ".tsx", ".json"],
        mainFields: ["main"],
        modules: [
            "node_modules",
            path_1.join(root, "node_modules"),
            path_1.join(__dirname, "../node_modules"),
        ],
    };
    config.resolveLoader = {
        modules: config.resolve.modules,
    };
    config.output = {
        filename: isProduction ? "[name].[hash].js" : "[name].js",
        path: options.dist,
    };
    // Loaders
    config.module = {
        rules: [
            options.typescriptLoader,
            {
                test: /\.json$/,
                use: "json-loader",
            },
        ],
    };
    config.externals = [
        function (context, request, callback) {
            if (/\.(css|less|scss)$/.test(request)) {
                var chunks = request.split("/");
                return callback(null, "{" + chunks[chunks.length - 1] + ": \"\"};");
            }
            callback();
        },
    ];
    // Plugins
    config.plugins = [
        // remove outdir
        new CleanWebpackPlugin([options.dist], {
            root: root,
            verbose: false,
        }),
        new CopyPlugin(options.assets ? [{
                from: options.assets, to: "./",
            }] : []),
    ];
    if (isProduction) {
        config.bail = true;
        config.plugins.push(new webpack_1.LoaderOptionsPlugin({
            debug: false,
            minimize: true,
        }));
    }
    config.node = {
        Buffer: false,
        __dirname: true,
        __filename: true,
    };
    config.target = "node";
    config.externals = [nodeExternals()];
    return config;
};
//# sourceMappingURL=node.js.map