"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Experimental
 *
 * Reload webpack dev server only if a remote server is up.
 * This is useful if we have wds + nodemon
 *
 * @param options
 */
exports.synchronize = function (options) {
    if (options === void 0) { options = {}; }
    var http = require("http");
    var Server = require("webpack-dev-server/lib/Server");
    var sendStats = Server.prototype._sendStats;
    var hostname = options.hostname || "localhost";
    var port = options.port || 3000;
    var delay = options.delay || 800;
    var retry = options.retry || 4;
    var log = function (message) {
        if (options.verbose) {
            // tslint:disable-next-line
            console.log(message);
        }
    };
    function tryUntilSuccess(o, i, callback) {
        if (i > retry) {
            log("webpack: Server not found.");
            callback(null);
            return;
        }
        log("webpack: Check server until (" + i + "/" + retry + ")");
        var req = http.request({
            hostname: o.hostname,
            port: o.port,
        }, function (res) {
            var acc = "";
            res.on("data", function (msg) { return acc += msg.toString("utf-8"); });
            res.on("end", function () {
                if (acc.indexOf("app") > -1) {
                    log("webpack: Connected.");
                    callback(null);
                }
                else {
                    log("webpack: Server is't ready, retry...");
                    setTimeout(function () {
                        tryUntilSuccess(o, i + 1, callback);
                    }, delay);
                }
            });
        });
        req.setTimeout(delay);
        req.end();
        req.on("error", function () {
            log("webpack: Server is't started, retry...");
            setTimeout(function () {
                tryUntilSuccess(options, i + 1, callback);
            }, delay);
        });
    }
    Server.prototype._sendStats = function _sendStats() {
        var args = arguments;
        var self = this;
        tryUntilSuccess({
            port: port,
            hostname: hostname,
        }, 0, function () {
            sendStats.apply(self, args);
        });
    };
};
//# sourceMappingURL=synchronize.js.map